﻿using System;
using System.ComponentModel;

namespace ELTE.Windows.CoursesListInModelView.ViewModel
{
    /// <summary>
    /// Általános változásjelző típusa.
    /// </summary>
    public abstract class ViewModelBase : INotifyPropertyChanged
    {
        /// <summary>
        /// Tulajdonság ellenőrzés végrehajtása.
        /// </summary>
        protected Boolean ValidateProperty { get; private set; }

        /// <summary>
        /// Általános változásjelző példányosítása.
        /// </summary>
        /// <param name="validateProperty">Tulajdonság ellenőrzés végrehajtása.</param>
        protected ViewModelBase(Boolean validateProperty = true)
        {
            ValidateProperty = true;
        }

        /// <summary>
        /// Tulajdonság változásának eseménye.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Tulajdonság változása ellenőrzéssel.
        /// </summary>
        /// <param name="propertyName">Tulajdonság neve.</param>
        protected virtual void OnPropertyChanged(String propertyName)
        {
            if (ValidateProperty && TypeDescriptor.GetProperties(this)[propertyName] == null)
            {
                throw new Exception("Invalid property name: " + propertyName);
            }

            if (PropertyChanged != null)
            {
                PropertyChangedEventArgs e = new PropertyChangedEventArgs(propertyName);
                PropertyChanged(this, e);
            }
        }
    }
}
