﻿using System;
using System.Data;
using System.Data.SqlClient;

namespace ELTE.Data.SimpleCommandUsage
{
    class Program
    {
        static void Main(string[] args)
        {
            // adatbázis-kapcsolat létrehozása
            SqlConnection connection = new SqlConnection("server = localhost; database = TestTables; Persist Security Info=False; Integrated Security = SSPI");

            try
            {
                connection.Open(); // kapcsolat megnyitása
                Console.WriteLine("Kapcsolat létrehozva!");
            }
            catch (SqlException ex) // ha nem sikerült, akkor SqlException-t kapunk
            {
                Console.WriteLine("Nem sikerült kapcsolódni az adatbázishoz:" + Environment.NewLine + ex.Message);
            }

            if (connection != null && connection.State == ConnectionState.Open) // ha nyitva van a kapcsolat
            {
                // hozzunk létre egy parancs objektumot 
                SqlCommand selectCountCommand = connection.CreateCommand();
                // megadjuk a parancsszöveget, ki akarjuk olvasni a sorok számát
                selectCountCommand.CommandText = "SELECT COUNT(*) FROM FirstTable";

                Int32 rowCount = 0;
                try
                {
                    // végrehajtjuk a parancsot, és kiolvassuk a kapott egész értéket
                    rowCount = Convert.ToInt32(selectCountCommand.ExecuteScalar());
                }
                catch (SqlException ex)
                {
                    Console.WriteLine("Nem sikerült kiolvasni az adatokat:" + Environment.NewLine + ex.Message);
                }

                Console.WriteLine("A sorok száma: " + rowCount.ToString());

                // szúrjunk be egy újabb sort a táblába
                SqlCommand insertCommand = connection.CreateCommand();
                insertCommand.CommandText = "INSERT INTO FirstTable VALUES (102, 'teszt3')";

                try
                {
                    // végrehajtjuk az utasítást, a visszatérési érték a módosított sorok száma 
                    rowCount = insertCommand.ExecuteNonQuery();
                    Console.WriteLine("Beszúrás megtörtént, " + rowCount.ToString() + " sor módosítva");
                }
                catch (SqlException ex)
                {
                    Console.WriteLine("Nem sikerült beírni az adatokat:" + Environment.NewLine + ex.Message);
                }

                // olvassuk ki a tábla adatait
                SqlCommand selectAllCommand = connection.CreateCommand();
                selectAllCommand.CommandText = "SELECT * FROM FirstTable";

                SqlDataReader dataReader = null; // olvasó objektum az adatok kiolvasásához
                try
                {
                    // lefuttatjuk az olvasás műveletet, az eredményt betesszük az adatolvasó objektumba
                    dataReader = selectAllCommand.ExecuteReader();
                    Console.WriteLine("Adatok beolvasva!");
                }
                catch (SqlException ex)
                {
                    Console.WriteLine("Nem sikerült kiolvasni az adatokat:" + Environment.NewLine + ex.Message);
                }

                if (dataReader != null) // ha sikerült kiolvasni az adatokat
                {
                    Console.WriteLine("A tábla tartalma:");
                    // olvasssuk ki az adatolvasóban eltárolt értékeket, ezt soronként tehetjük meg
                    while (dataReader.Read()) // sorléptetés, hamis lesz, ha végére érünk a táblának
                    {
                        // kiolvassuk az első (int = Int32) és a második (varchar = String) mezőt
                        Console.WriteLine(dataReader.GetInt32(0).ToString() + "," + dataReader.GetString(1));
                    }
                    // lezárjuk az olvasó objektumot
                    dataReader.Close();
                }

                SqlCommand deleteCommand = connection.CreateCommand();
                deleteCommand.CommandText = "DELETE FROM FirstTable WHERE FirstColumn = @id";
                // paraméter hozzáadása, a felhasználótól bekért adatok esetén véd az SQL injection támadások ellen
                deleteCommand.Parameters.Add("@id", SqlDbType.Int);
                deleteCommand.Parameters["@id"].Value = 102;

                try
                {
                    // végrehajtjuk az utasítást, a visszatérési érték a módosított sorok száma 
                    rowCount = deleteCommand.ExecuteNonQuery();
                    Console.WriteLine("Törlés megtörtént, " + rowCount.ToString() + " sor módosítva");
                }
                catch (SqlException ex)
                {
                    Console.WriteLine("Nem sikerült törölni az adatokat:" + Environment.NewLine + ex.Message);
                }

                // lezárjuk az adatbázis kapcsolatot
                if (connection != null && connection.State == System.Data.ConnectionState.Open)
                    connection.Close();

                Console.ReadKey();
            }
        }
    }
}
