﻿using System;
using System.Windows;
using ELTE.Data.TravelAgency.RentManager.View;
using ELTE.Data.TravelAgency.RentManager.ViewModel;

namespace ELTE.Data.TravelAgency.RentManager
{
    /// <summary>
    /// Interaction logic for App.xaml
    /// </summary>
    public partial class App : Application
    {
        private TravelAgencyViewModel _ViewModel;
        private LoginWindow _LoginWindow;
        private MainWindow _MainWindow;
        private NewRentWindow _NewRentWindow;

        public App()
        {
            _ViewModel = new TravelAgencyViewModel();
            _ViewModel.LoginFailed += new System.EventHandler(ViewModel_LoginFailed); // nézetmodell eseményeinek kezelése
            _ViewModel.LoginSuccess += new System.EventHandler(ViewModel_LoginSuccess);
            _ViewModel.NewRent += new System.EventHandler(ViewModel_NewRent);
            _ViewModel.RentCancel += new System.EventHandler(ViewModel_RentCancel);
            _ViewModel.RentSave += new System.EventHandler(ViewModel_RentSave);
        }

        protected override void OnStartup(StartupEventArgs e)
        {
            base.OnStartup(e);

            _LoginWindow = new LoginWindow();
            _LoginWindow.DataContext = _ViewModel;
            _LoginWindow.Show();

        }

        private void ViewModel_LoginFailed(object sender, EventArgs e)
        {
            MessageBox.Show("A bejelentkezés sikertelen.", "Utazási ügynökség", MessageBoxButton.OK, MessageBoxImage.Error);
        }

        private void ViewModel_LoginSuccess(object sender, EventArgs e)
        {
            _MainWindow = new MainWindow();
            _MainWindow.DataContext = _ViewModel;
            _MainWindow.Show();
            if (_LoginWindow != null)
                _LoginWindow.Close(); // bezárjuk a bejelentkező ablakot, és megnyitjuk a főablakot
        }

        private void ViewModel_NewRent(object sender, EventArgs e)
        {
            _NewRentWindow = new NewRentWindow();
            _NewRentWindow.DataContext = _ViewModel;
            _NewRentWindow.ShowDialog();
        }

        private void ViewModel_RentCancel(object sender, EventArgs e)
        {
            if (_NewRentWindow != null)
                _NewRentWindow.Close();
        }

        private void ViewModel_RentSave(object sender, EventArgs e)
        {
            if (_NewRentWindow != null)
                _NewRentWindow.Close();
        }
    }
}
